@@ -4,10 +4,7 @@ fn byte_to_hex(byte: &u8) -> String {
 
 /// Serializes bytes into a hex string
 pub fn to_hex_string<T: Clone + Into<Vec<u8>>>(bytes: &T) -> String {
-    let hex_vec: Vec<String> = bytes.clone().into()
-        .iter()
-        .map(byte_to_hex)
-        .collect();
+    let hex_vec: Vec<String> = bytes.clone().into().iter().map(byte_to_hex).collect();
 
     hex_vec.join("")
 }
